dart_api_query library

Library Dart Api Query inspired by vue-api-query.

Classes

ApiQuery<T extends Schema>
Adapter for connect with api
Builder
Create a query url with different params
Parser
Parse attributes from Builder into query string
QueryParameters
Query Parameters names of query builder.
ResourceCollection
Wrapped response collection from json and helper to assign properties on Schema model
ResourceObject
Wrapped response from json and helper to assign properties on Schema model
ResourcePagination<T extends Schema>
Wrapped response collection from json and helper to assign properties on Schema model
Schema
Schemas provide getters and setters that help us transform responses into objects with their own attributes, relationships, related objects and errors.
Serializer
Serializer dio response to scheme resource object or resource collection
StringifyOptions
Stringify options for handle stringify

Enums

ArrayFormat
How to parse array format to use on stringify function
Charset
Charset type to use on stringify function
RfcFormat
Rfc format to use on stringify function

Exceptions / Errors

DeserializationException
A deserialization exception
SerializationException
A serialization exception