QueryParameters class
Query Parameters names of query builder.
Constructors
Properties
- append ↔ String
-
Parameter name for append.
getter/setter pair
- fields ↔ String
-
Parameter name for fields.
getter/setter pair
- filter ↔ String
-
Parameter name for filter.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- include ↔ String
-
Parameter name for include.
getter/setter pair
- limit ↔ String
-
Parameter name for limit.
getter/setter pair
- page ↔ String
-
Parameter name for page.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sort ↔ String
-
Parameter name for sort.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited