Serializer class

Serializer dio response to scheme resource object or resource collection

Constructors

Serializer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserialize(Map<String, dynamic> responseData) ResourceObject
From responseData of dio to Resource Object
deserializeMany(dynamic responseData) ResourceCollection
From responseData of dio to Resource Collection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(ResourceObject document) String
Serialize ResourceObject attributes to json string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited