StringifyOptions class

Stringify options for handle stringify

Constructors

StringifyOptions({String? delimiter, bool? strictNullHandling, bool? skipNulls, bool? encode, dynamic encoder(dynamic, Charset?, RfcFormat?)?, ArrayFormat? arrayFormat, bool? commaRoundTrip, bool? indices, int sort(dynamic, dynamic)?, dynamic serializeDate(DateTime)?, RfcFormat? format, String formatter(dynamic)?, bool? encodeValuesOnly, bool? addQueryPrefix, bool? allowDots, Charset? charset, bool? charsetSentinel})
Constructor with optional parameters
StringifyOptions.fromDefaults()
Get default stringify options
factory
StringifyOptions.normalize(StringifyOptions? opts)
Normalize stringify options if optional variable not is included
factory

Properties

addQueryPrefix bool?
Add query prefix
getter/setter pair
allowDots bool?
Allow dots
getter/setter pair
arrayFormat ArrayFormat?
Format array to use
getter/setter pair
charset Charset?
Charset to use
getter/setter pair
charsetSentinel bool?
With charset sentinel
getter/setter pair
commaRoundTrip bool?
CommaRoundTrip
getter/setter pair
delimiter String?
Delimiter
getter/setter pair
encode bool?
Encode query
getter/setter pair
encoder ↔ dynamic Function(dynamic, Charset?, RfcFormat?)?
Function to use to encoder string
getter/setter pair
encodeValuesOnly bool?
Encode values only
getter/setter pair
format RfcFormat?
Rfc format to use
getter/setter pair
formatter String Function(dynamic)?
Function to use based on rfc format
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
indices bool?
With indices
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializeDate ↔ dynamic Function(DateTime)?
Function to convert datetime
getter/setter pair
skipNulls bool?
Skip nulls
getter/setter pair
sort int Function(dynamic, dynamic)?
Function to sort
getter/setter pair
strictNullHandling bool?
Strict null handling
getter/setter pair

Methods

merge(StringifyOptions opts) StringifyOptions
Merge Current StringifyOptions with override values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited