Parser class
Parse attributes from Builder into query string
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appends(
) → void - Parser appends
-
fields(
) → void - Parser fields
-
filters(
) → void - Parser filters
-
hasAppends(
) → bool - Builder has appends
-
hasFields(
) → bool - Builder has fields
-
hasFilters(
) → bool - Builder has filters
-
hasIncludes(
) → bool - Builder has includes
-
hasLimit(
) → bool - Builder has limit
-
hasPage(
) → bool - Builder has page
-
hasPayload(
) → bool - Builder has payload
-
hasSorts(
) → bool - Builder has sorts
-
includes(
) → void - Parser includes
-
limit(
) → void - Parser limit
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
page(
) → void - Parser page
-
parameterNames(
) → QueryParameters - Get a parameter names from model
-
payload(
) → void - Parser payload
-
prepend(
) → String - Get query prepend symbol
-
query(
) → String - Final query string
-
reset(
) → void - Reset query string
-
sorts(
) → void - Parser sorts
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited